EdgeBehavior enum

Edge behavior for focus traversal within a scope.

Inheritance
Available extensions

Values

parentScope → const EdgeBehavior

Focus exits to parent scope's next focusable.

const EdgeBehavior(0)
closedLoop → const EdgeBehavior

Focus wraps from last to first within this scope.

const EdgeBehavior(1)
stop → const EdgeBehavior

Focus stays on boundary element.

const EdgeBehavior(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The native value for this edge behavior.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) EdgeBehavior
Create an EdgeBehavior from a native value.

Constants

values → const List<EdgeBehavior>
A constant List of the values in this enum, in order of their declaration.