changed property
set
changed
(FocusCallback? callback)
Set a callback to be invoked when focus changes. Pass null to remove the callback.
Implementation
set changed(FocusCallback? callback);
Set a callback to be invoked when focus changes. Pass null to remove the callback.
set changed(FocusCallback? callback);