focusLeft abstract method
Move focus to the nearest focusable node to the left. Returns true if focus was moved.
Implementation
bool focusLeft();
Move focus to the nearest focusable node to the left. Returns true if focus was moved.
bool focusLeft();