focusRight abstract method
Move focus to the nearest focusable node to the right. Returns true if focus was moved.
Implementation
bool focusRight();
Move focus to the nearest focusable node to the right. Returns true if focus was moved.
bool focusRight();