isFocusInArtboard abstract method

bool isFocusInArtboard(
  1. int artboardPtr
)

Check if the primary focus is inside the given artboard (or a nested artboard within it). Returns true if the focused element's artboard is the given artboard or a descendant of it. artboardPtr should be a native artboard pointer address.

Implementation

bool isFocusInArtboard(int artboardPtr);