primaryFocusArtboardPtr abstract method
Get the root native artboard pointer address that contains the primary focus. This walks up the nested artboard chain to find the topmost artboard. Returns null if there is no focus or the focusable has no artboard.
Implementation
int? primaryFocusArtboardPtr();