scrollIntoView property

set scrollIntoView (ScrollIntoViewCallback? callback)

Set a callback to be invoked when focus changes to an element in a Dart-mounted artboard (root artboard with no native host). This allows Dart to handle scrolling the focused element into view. Pass null to remove the callback.

Implementation

set scrollIntoView(ScrollIntoViewCallback? callback);