setWorldBounds abstract method

void setWorldBounds(
  1. double minX,
  2. double minY,
  3. double maxX,
  4. double maxY,
)

Set the world bounds for this node (for directional navigation). Bounds are in root artboard space and used for spatial navigation calculations. Call this during your update cycle when the node's position/size changes.

Implementation

void setWorldBounds(double minX, double minY, double maxX, double maxY);