ScrollIntoViewCallback typedef

ScrollIntoViewCallback = void Function(({double maxX, double maxY, double minX, double minY}) bounds, int artboardPtr)

Callback type for scroll-into-view requests from Dart-mounted artboards. Called when focus changes to an element in an artboard whose root is mounted by Dart (has no native host). Parameters:

  • bounds: world bounds of the focused element to scroll into view
  • artboardPtr: pointer to the artboard directly hosted by the Dart root

Implementation

typedef ScrollIntoViewCallback = void Function(
  ({double minX, double minY, double maxX, double maxY}) bounds,
  int artboardPtr,
);