Layout class

Constructors

Layout(double left, double top, double width, double height)
Layout.clone(Layout source)
Layout.zero()

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
left ↔ double
getter/setter pair
offset → Offset
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
no setter
top ↔ double
getter/setter pair
width ↔ double
getter/setter pair

Methods

equals(Layout v) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(Layout from, Layout to, double f) → Layout