LayoutPadding class

Constructors

LayoutPadding(double left, double top, double right, double bottom)
LayoutPadding.clone(LayoutPadding source)
LayoutPadding.zero()

Properties

bottom → double
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
final

Methods

equals(LayoutPadding v) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited