LayoutStyle class abstract

Constructors

LayoutStyle()

Properties

alignContent ↔ LayoutAlign
getter/setter pair
alignItems ↔ LayoutAlign
getter/setter pair
alignSelf ↔ LayoutAlign
getter/setter pair
aspectRatio ↔ double?
getter/setter pair
direction ↔ LayoutDirection
getter/setter pair
display ↔ LayoutDisplay
getter/setter pair
flex ↔ double?
getter/setter pair
flexBasis ↔ LayoutValue
getter/setter pair
flexDirection ↔ LayoutFlexDirection
getter/setter pair
flexGrow ↔ double?
getter/setter pair
flexShrink ↔ double?
getter/setter pair
flexWrap ↔ LayoutWrap
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
justifyContent ↔ LayoutJustify
getter/setter pair
justifyItems ↔ LayoutJustify
getter/setter pair
justifySelf ↔ LayoutJustify
getter/setter pair
overflow ↔ LayoutOverflow
getter/setter pair
positionType ↔ LayoutPosition
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
getBorder(LayoutEdge edge) → LayoutValue
getDimension(LayoutDimension dimension) → LayoutValue
getGap(LayoutGutter gutter) → LayoutValue
getMargin(LayoutEdge edge) → LayoutValue
getMaxDimension(LayoutDimension dimension) → LayoutValue
getMinDimension(LayoutDimension dimension) → LayoutValue
getPadding(LayoutEdge edge) → LayoutValue
getPosition(LayoutEdge edge) → LayoutValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBorder(LayoutEdge edge, LayoutValue value) → void
setDimension(LayoutDimension dimension, LayoutValue value) → void
setGap(LayoutGutter gutter, LayoutValue value) → void
setGridLine(LayoutGridLinePosition position, LayoutGridLine line) → void
setGridTracks(LayoutGridCollection collection, List<LayoutGridTrack> tracks) → void
Replaces the track list of collection with tracks.
setMargin(LayoutEdge edge, LayoutValue value) → void
setMaxDimension(LayoutDimension dimension, LayoutValue value) → void
setMinDimension(LayoutDimension dimension, LayoutValue value) → void
setPadding(LayoutEdge edge, LayoutValue value) → void
setPosition(LayoutEdge edge, LayoutValue value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

make() → LayoutStyle