textureDisplaying function

RenderTexture? textureDisplaying(
  1. Artboard artboard
)

The texture displaying artboard, live or not. One artboard instance is one animation state, so only one texture may show it at a time.

Implementation

RenderTexture? textureDisplaying(Artboard artboard) =>
    _displayingTexture[artboard];