isDisposed property
bool
get
isDisposed
Returns true if this VM has been disposed. After disposal, all operations on this state are invalid.
Implementation
bool get isDisposed;
Returns true if this VM has been disposed. After disposal, all operations on this state are invalid.
bool get isDisposed;