rive_native library

Classes

AABB
AdvanceRequestInterface
Interface for requesting advance/repaint from a higher-level controller.
Animation
A Rive animation that can be played on an artboard.
Artboard
A Rive artboard containing animations, state machines, and components.
ArtboardPainter
ArtboardWidgetPainter<T extends ProceduralPainter>
ArtboardWidgetRiveRenderer
AudioAsset
An audio asset embedded in or referenced by a Rive file.
AudioSource
BasicArtboardPainter
BindableArtboard
A reference to an artboard that can be bound to a view model property.
BitFieldLoc
Location of an integer within a bitfield. https://en.wikipedia.org/wiki/C_syntax#Bit_fields
BooleanInput
A boolean state machine input.
CallbackHandler
ClosureCallbackHandler
Component
A component within a Rive artboard (node, bone, shape, etc.).
CursorVisualPosition
CustomBooleanProperty
A boolean custom property on a Rive event.
CustomNumberProperty
A numeric custom property on a Rive event.
CustomProperty<T>
A custom property on a Rive event.
CustomPropertyInterface<T>
Interface for custom properties attached to Rive events.
CustomStringProperty
A string custom property on a Rive event.
DashPathEffect
DataEnum
A view model enum that represents a list of values.
EmptyCallbackHandler
Event
A Rive event emitted by a state machine.
EventInterface
Interface for Rive events emitted by state machines.
EventListenerInterface
Interface for listening to Rive events from a state machine.
Factory
Factory for creating Rive rendering objects.
File
A loaded Rive file containing artboards, animations, and view models.
FileAsset
Base class for all file assets in a Rive file.
FileAssetInterface
Interface for Rive file assets (images, fonts, audio).
FlutterRenderer
FlutterRiveRenderBox
FlutterRiveRendererWidget
Font
FontAsset
A font asset embedded in or referenced by a Rive file.
GeneralEvent
A general purpose Rive event with optional custom properties.
HitTester
IAABB
ImageAsset
An image asset embedded in or referenced by a Rive file.
IndexRenderBuffer
Input
Base class for state machine inputs.
Mat2D
NumberInput
A numeric state machine input.
OpenUrlEvent
A Rive event that requests opening a URL.
PathCommand
PathInterface
PathMeasure
ProceduralPainter
ProjectionResult
Result of projecting a point onto a segment.
RawTextInput
A low level text input helper. Takes high level input and creates shaped text, selection, and cursor. Does not handle scrolling internally.
RenderBuffer
Renderer
RenderGradient
RenderImage
RenderLinearGradient
RenderPaint
RenderPath
RenderRadialGradient
RenderText
RenderTexture
RenderTexturePainter
A painting context passed to a Rive RenderTexture widget which will invoke the paint method as necessary to paint into the texture with a Rive renderer.
Rive
RiveArtboardWidget
RiveDefaults
RiveFileWidget
RiveNative
RiveNativeRenderBox
RivePainter
Base class for a Rive painter.
RiveProceduralRenderingWidget
RiveRenderBox<T extends RivePainter>
Segment2D
A line segment with a discrete start and end.
SingleAnimationPainter
StateMachine
A Rive state machine that drives animations based on inputs and logic.
StateMachinePainter
TextValueRunRuntime
A text run value in a Rive artboard.
TransformComponents
TransformingHitTester
A HitTester with a settable transform. We can roll this into HitTester if we like it.
TriggerInput
A trigger state machine input.
TrimPathEffect
UnimplementedRenderTexture
UnknownAsset
An unrecognized asset type in a Rive file.
Vec2D
VertexRenderBuffer
ViewModel
A Rive View Model as created in the Rive editor.
ViewModelInstance
An instance of a Rive ViewModel that can be used to access and modify properties in the view model.
ViewModelInstanceArtboard
A Rive view model property that holds a reference to an artboard.
ViewModelInstanceAssetImage
A Rive view model property of type RenderImage that represents an asset image value.
ViewModelInstanceBoolean
A Rive view model property of type bool that represents a boolean value.
ViewModelInstanceCallbacks
ViewModelInstanceColor
A Rive view model property of type Color that represents a color value.
ViewModelInstanceEnum
A Rive view model property of type String that represents an enumerator value.
ViewModelInstanceList
A Rive view model property of type List<ViewModelInstance> that represents a list of view model instances.
ViewModelInstanceNumber
A Rive view model property of type double that represents a number value.
ViewModelInstanceObservableValue<T>
ViewModelInstanceString
A Rive view model property of type String that represents a string value.
ViewModelInstanceSymbolListIndex
A Rive view model property of type int that represents the list index.
ViewModelInstanceTrigger
A Rive view model property of type bool that represents a trigger value.
ViewModelInstanceValue
ViewModelProperty
A representation of a property in a Rive view model.

Enums

CursorBoundary
CustomPropertyType
The type of a custom property on an event.
DataType
The type of data that a view model property can hold.
EventType
The type of a Rive event.
Fit
HitResult
Result of a hit test or pointer event on a state machine.
Key
Keyboard key codes for input events.
KeyModifiers
Keyboard modifier keys for input events.
OpenUrlTarget
The browser target for opening a URL from an OpenUrlEvent.
PaintingStyle
PathDirection
PathFillRule
PathFillType
PathVerb
RiveHitTestBehavior
How to behave during hit tests on Rive Listeners (hit targets).
TrimPathMode

Mixins

AdvanceRequestMixin
Shared implementation of AdvanceRequestInterface.
DeformableBehavior
EventListenerMixin
EventPropertyMixin
Mixin for implementing the EventInterface properties.
RiveArtboardLayoutMixin
A mixin that provides artboard layout options to a RivePainter.
RivePointerEventMixin
Mixin that provides methods for handling pointer events on a RivePainter.
RiveTickerAwarePainterMixin
Mixin that provides access to ticker state for painters.
ViewModelInstanceCallbackMixin
ViewModelInstanceObservableValueMixin<T>
A mixin that implements the ViewModelInstanceObservableValue interface and provides the basic functionality for handling listeners (observables) and notifying them of changes. This allows users to observe changes to the underlying Rive property value.

Extensions

FileAssetExtension on FileAsset
Extension providing convenience accessors for FileAsset properties.

Typedefs

AssetLoaderCallback = bool Function(FileAsset fileAsset, Uint8List? bytes)
Callback for custom asset loading.
OnRiveEvent = void Function(Event event)
A Rive event listener callback