BasicArtboardPainter class
base
Inheritance
Mixed-in types
Implementers
Properties
alignment
↔ Alignment
Controls how the artboard is aligned within its bounds.
getter/setter pair inherited
artboard
→ Artboard ?
no setter override
fit
↔ Fit
Controls how the artboard is scaled and positioned within its bounds.
getter/setter pair inherited
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
Whether any listeners are currently registered.
no setter inherited
isTickerActive
→ bool
Whether the animation ticker is currently active.
no setter inherited
lastSize
→ Size
no setter inherited
layoutScaleFactor
↔ double
The scale factor to use for a fit of type Fit.layout.
getter/setter pair inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
size
→ Size
no setter inherited
Methods
addListener (VoidCallback listener )
→ void
Register a closure to be called when the object changes.
inherited
advance (double elapsedSeconds )
→ bool
Called each frame to advance the animation.
override
artboardChanged (Artboard artboard )
→ void
Called when the underlying artboard changes.
override
dispose ()
→ void
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners ()
→ void
Call all the registered listeners.
inherited
paint (Renderer renderer , Size size , double paintPixelRatio )
→ void
Called each frame to paint the artboard.
override
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
scheduleRepaint ()
→ void
Request a repaint of the artboard.
inherited
toString ()
→ String
A string representation of this object.
inherited