CustomPropertyInterface<T> class abstract interface

Interface for custom properties attached to Rive events.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this property.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type CustomPropertyType
The data type of this property.
no setter
value → T
The value of this property.
no setter

Methods

dispose() → void
Releases resources associated with this property.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited