DataType enum
The type of data that a view model property can hold.
Values
- none → const DataType
-
None
- string → const DataType
-
String
- number → const DataType
-
Number
- boolean → const DataType
-
Boolean
- color → const DataType
-
Color
- list → const DataType
-
List
- enumType → const DataType
-
Enum
- trigger → const DataType
-
Trigger
- viewModel → const DataType
-
View Model
- integer → const DataType
-
Integer
- symbolListIndex → const DataType
-
Symbol list index
- image → const DataType
-
Asset Image
- artboard → const DataType
-
Artboard
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited