property method
Retrieve a custom property from the event with the given name.
Implementation
@override
CustomProperty? property(String name) {
final property = properties[name];
return property;
}
Retrieve a custom property from the event with the given name.
@override
CustomProperty? property(String name) {
final property = properties[name];
return property;
}