A Rive view model property of type bool that represents a trigger value.
Note the bool value will always be false, and is only used to represent
the underlying type. The property is fired by calling the trigger method,
or by setting the value to true, which will call trigger and
immediately set back to false.
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- numberOfListeners → int
-
The number of listeners attached to the property.
This is useful for testing purposes.
no setterinherited
- rootViewModelInstance → ViewModelInstance
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ bool
-
Gets the value of the property
getter/setter pairinherited
-
valueStream
→ Stream<
bool> -
Returns a stream that emits the value of the property.
no setterinherited
Methods
-
addListener(
void callback(bool value)) → void -
Adds a listener/callback that will be called when the property value
changes
inherited
-
clearListeners(
) → void -
Clears all listeners from the property
inherited
-
dispose(
) → void -
Disposes of the property. This removes all listeners and cleans up all
underlying resources.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
void callback(bool value)) → void -
Removes a listener/callback from the property
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
) → void - Invokes the trigger for the property
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited