rive_text library

Classes

BreakLinesResult
ColorGlyphLayer
A single layer of a color glyph (emoji), with its own path and paint.
Font
FontAxis
FontAxisCoord
FontFeature
FontTag
GlyphLine
GlyphLookup
Stores the glyph index representing the code unit at index i.
GlyphRun
GradientStop
A gradient color stop (offset + ARGB color).
LineRunGlyph
Paragraph
RawPath
RawPathCommand
TextHelper
TextRun
A representation of a styled section of text in Rive.
TextShapeResult

Enums

ColorGlyphPaintType
Paint type for a color glyph layer.
FontInitStatus
RawPathVerb
TextAlign
TextDirection
TextOrigin
TextOverflow
TextSizing
TextTrimBottom
Bottom edge the vertical bounding box is trimmed to.
TextTrimTop
Top edge the vertical bounding box is trimmed to.
TextWrap
VerticalTextAlign

Constants

textTrimBottomShift → const int
textTrimFieldMask → const int
textTrimTopShift → const int
Text.verticalTrimValue packs an independent top and bottom trim edge so new edge types can be added later without introducing a new property. The top edge occupies the low byte and the bottom edge the next byte; the remaining bits (and the high 16) are reserved for future values.