Distances from the baseline to the top of capital / lowercase letters, stored negative (up is -Y) like ascent. Both fall back to ascent when the font does not provide the metric.
double get capHeight;