GradientStop class

A gradient color stop (offset + ARGB color).

Constructors

GradientStop(double offset, int color)

Properties

color int
final
hashCode int
The hash code for this object.
no setterinherited
offset double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited