textTrimTopShift top-level constant

int const textTrimTopShift

Text.verticalTrimValue packs an independent top and bottom trim edge so new edge types can be added later without introducing a new property. The top edge occupies the low byte and the bottom edge the next byte; the remaining bits (and the high 16) are reserved for future values.

Implementation

const int textTrimTopShift = 0;