scripting_workspace library

Classes

AutocompleteEntry
AutocompleteResult
CompileAndSignResult
CompiledModule
CompileResult
DefinitionResult
FindInFilesMatch
FindInFilesResult
FormatOp
FormatOpErase
FormatOpInsert
FormatResult
HighlightDiffEntry
HighlightResult
HighlightScopeStyle
ImplementedType
ImplementedTypeProperty
RegisteredModule
ScriptFindResults
ScriptingWorkspace
A workspace represents a collection of files that are likely related (usually part of a single Rive file).
ScriptingWorkspaceResponseResult
ScriptPosition
ScriptProblem
ScriptProblemResult
ScriptRange
ShaderCompileError
A per-source shader-bake failure reported by ScriptingWorkspace.compileAndSign (e.g. a shader that requested an HLSL variant but failed to compile it). When present, the corresponding shader was NOT embedded for that backend.
VMResult

Exceptions / Errors

ScriptingWorkspaceClosedError
An error thrown when attempting to use a ScriptingWorkspace that has been closed or is in the process of closing.