AutocompleteEntry class

Constructors

AutocompleteEntry({required ScriptRange range, required String text, required Uint32List matchedIndices})

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchedIndices → Uint32List
final
range → ScriptRange
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

read(BinaryReader reader) → AutocompleteEntry