shaderErrors property
Non-fatal shader-bake failures. Empty on success. A non-empty list means one or more shaders were exported missing a requested backend variant.
Implementation
final List<ShaderCompileError> shaderErrors;
Non-fatal shader-bake failures. Empty on success. A non-empty list means one or more shaders were exported missing a requested backend variant.
final List<ShaderCompileError> shaderErrors;