CompileResult class

Constructors

CompileResult({required Uint8List bytecode, Iterable<CompiledModule> dependencies = const Iterable.empty(), Iterable<String> dependents = const Iterable.empty()})

Properties

bytecode → Uint8List
final
dependencies → Iterable<CompiledModule>
final
dependents → Iterable<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

read(BinaryReader reader) → CompileResult?