FindInFilesMatch class

Constructors

FindInFilesMatch({required int line, required String beforeMatch, required String matchText, required String afterMatch})

Properties

afterMatch → String
final
beforeMatch → String
final
hashCode → int
The hash code for this object.
no setterinherited
line → int
final
matchText → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited