FindInFilesResult class

Constructors

FindInFilesResult({required List<ScriptFindResults> results})

Properties

hashCode → int
The hash code for this object.
no setterinherited
results → List<ScriptFindResults>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty → FindInFilesResult
final

Static Methods

read(BinaryReader reader) → FindInFilesResult?