FormatResult class

Constructors

FormatResult({required List<FormatOp> operations})

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → List<FormatOp>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty → FormatResult
final

Static Methods

read(BinaryReader reader) → FormatResult