HighlightDiffEntry class

Constructors

HighlightDiffEntry({required HighlightDiffChangeType changeType, required int lineIndex, required int lineCount, required int destLineIndex})

Properties

changeType → HighlightDiffChangeType
final
destLineIndex → int
For removed entries: the line in the destination where this removed content should be displayed. For added entries: same as lineIndex.
final
hashCode → int
The hash code for this object.
no setterinherited
lineCount → int
final
lineIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited