HighlightResult class

Constructors

HighlightResult(HighlightResultType type, {List<HighlightDiffEntry> diffs = const []})
const

Properties

diffs → List<HighlightDiffEntry>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → HighlightResultType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

read(BinaryReader reader) → HighlightResult

Constants

computed → const HighlightResult
unknown → const HighlightResult