ScriptPosition class

Implemented types

Constructors

ScriptPosition({required int line, required int column})
const

Properties

column → int
final
hashCode → int
The hash code for this object.
no setteroverride
line → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(ScriptPosition other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

read(BinaryReader reader) → ScriptPosition