ScriptProblem class

Constructors

ScriptProblem({required ScriptRange range, required String message, required ScriptProblemType type})

Properties

hashCode → int
The hash code for this object.
no setteroverride
message → String
final
range → ScriptRange
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ScriptProblemType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

read(BinaryReader reader) → ScriptProblem