ScriptProblemResult class

Constructors

ScriptProblemResult({required String scriptName, required List<ScriptProblem> errors, required List<ScriptProblem> lintErrors, required List<ScriptProblem> lintWarnings})

Properties

errors → List<ScriptProblem>
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
lintErrors → List<ScriptProblem>
final
lintWarnings → List<ScriptProblem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty → ScriptProblemResult
final

Static Methods

read(BinaryReader reader) → ScriptProblemResult