ScriptRange class

Constructors

ScriptRange({required ScriptPosition begin, required ScriptPosition end})
const

Properties

begin → ScriptPosition
final
end → ScriptPosition
final
hashCode → int
The hash code for this object.
no setteroverride
isCollapsed → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

read(BinaryReader reader) → ScriptRange