setScriptSource abstract method

Future<HighlightResult> setScriptSource(
  1. String scriptId,
  2. String scriptName,
  3. String source, {
  4. bool highlight = false,
  5. int libraryId = 0,
  6. int libraryVersionId = 0,
})

Set the source code for the script with scriptId. libraryId and libraryVersionId scope it to a library version, zero scope is the host file.

Implementation

Future<HighlightResult> setScriptSource(
  String scriptId,
  String scriptName,
  String source, {
  bool highlight = false,
  int libraryId = 0,
  int libraryVersionId = 0,
});