TarjansDependencySorter<T extends Object> class abstract

Sorts dependencies for Actors even when cycles are present

Any nodes that form part of a cycle can be found in cycleNodes after sort. NOTE: Nodes isolated by cycles will not be found in _order or cycleNodes e.g. A -> B <-> C -> D isolates D when running a sort based on A

Inheritance
Implementers

Constructors

TarjansDependencySorter()

Properties

cycleNodes → HashSet<T>
no setter
hashCode → int
The hash code for this object.
no setterinherited
order → List<T>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependentsOf(T object) → Set<T>
inherited
findCycles(T n) → HashSet<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
inherited
sort(T root) → List<T>
override
toString() → String
A string representation of this object.
inherited
visit(T n) → bool
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited