primaryFocusBounds abstract method
Get the world bounds of the primary focus node. Returns null if there is no focus or the focused node has no bounds. Bounds are in root artboard space.
Implementation
({double minX, double minY, double maxX, double maxY})? primaryFocusBounds();