deferredBoundToOneTexture function
Whether this session can only ever replay into one texture, so a second one has to be refused however distinct its content is.
Implementation
bool deferredBoundToOneTexture(Factory factory) =>
factory is DeferredSessionFactory && factory.boundToOneTexture;