advanceDetachedViewModels abstract method
void
advanceDetachedViewModels()
Advances (resets) script-created view model instances that are detached from any bound view model tree. Call once at the end of each frame so fired triggers are consumed/re-armed. Mirrors the runtime's Artboard::advanceScriptedViewModels.
Implementation
void advanceDetachedViewModels();