rawGetField abstract method
lua_rawgetfield equivalent. Pushes onto the stack tk, where t is the
table at the given index. The access is raw, that is, it does not invoke
the __index metamethod. Returns the type of the pushed value.
Implementation
LuauType rawGetField(int index, String name);