Animation class abstract
A Rive animation that can be played on an artboard.
Use Artboard.animationAt or Artboard.animationNamed to obtain an animation instance.
Constructors
Properties
- duration → double
-
The total duration of the animation in seconds.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of this animation.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time ↔ double
-
The current playback time in seconds.
getter/setter pair
Methods
-
advance(
double elapsedSeconds) → bool -
Advances the animation by
elapsedSeconds. -
advanceAndApply(
double elapsedSeconds) → bool - Advances the animation and applies it to the artboard.
-
apply(
{double mix = 1.0}) → void -
Applies the animation to the artboard with the given
mixfactor. -
dispose(
) → void - Releases resources associated with this animation.
-
globalToLocalTime(
double seconds) → double - Converts a global time to the animation's local time.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited