GeneralEvent class abstract
A general purpose Rive event with optional custom properties.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of this event as defined in the Rive editor.
no setterinherited
-
properties
→ Map<
String, CustomProperty> -
Custom properties attached to this event, keyed by name.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondsDelay → double
-
The time in seconds since this event was triggered.
no setterinherited
- type → EventType
-
The type of this event.
no setterinherited
Methods
-
booleanProperty(
String name) → CustomBooleanProperty? -
Retrieve a boolean property from the event with the given
name.inherited -
dispose(
) → void -
Dispose the event.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
numberProperty(
String name) → CustomNumberProperty? -
Retrieve a number property from the event with the given
name.inherited -
property(
String name) → CustomProperty? -
Retrieve a custom property from the event with the given
name.inherited -
stringProperty(
String name) → CustomStringProperty? -
Retrieve a string property from the event with the given
name.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited