rive_text library
Classes
- BreakLinesResult
- ColorGlyphLayer
- A single layer of a color glyph (emoji), with its own path and paint.
- Font
- FontAxis
- FontAxisCoord
- FontFeature
- FontTag
- GlyphLine
- GlyphLookup
- Stores the glyph index representing the code unit at index i.
- GlyphRun
- GradientStop
- A gradient color stop (offset + ARGB color).
- LineRunGlyph
- Paragraph
- RawPath
- RawPathCommand
- TextHelper
- TextRun
- A representation of a styled section of text in Rive.
- TextShapeResult
Enums
- ColorGlyphPaintType
- Paint type for a color glyph layer.
- FontInitStatus
- RawPathVerb
- TextAlign
- TextDirection
- TextOrigin
- TextOverflow
- TextSizing
- TextWrap
- VerticalTextAlign
Functions
-
isWhiteSpace(
int c) → bool -
orderVisually(
List< GlyphRun> glyphRuns) → List<GlyphRun>