ColorGlyphLayer class
A single layer of a color glyph (emoji), with its own path and paint.
Constructors
-
ColorGlyphLayer({RawPath? path, ColorGlyphPaintType paintType = ColorGlyphPaintType.solid, int color = 0xFF000000, bool useForeground = false, List<
GradientStop> stops = const [], double x0 = 0, double y0 = 0, double x1 = 0, double y1 = 0, double r0 = 0, double r1 = 0, double startAngle = 0, double endAngle = 0, Uint8List? imageBytes, int imageWidth = 0, int imageHeight = 0, double imageBearingX = 0, double imageBearingY = 0, double imageExtentX = 0, double imageExtentY = 0})
Properties
- color → int
-
final
- endAngle → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageBearingX → double
-
final
- imageBearingY → double
-
final
- imageBytes → Uint8List?
-
Image data (only valid when paintType == image).
final
- imageExtentX → double
-
final
- imageExtentY → double
-
final
- imageHeight → int
-
final
- imageWidth → int
-
final
- paintType → ColorGlyphPaintType
-
final
- path → RawPath?
-
final
- r0 → double
-
final
- r1 → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAngle → double
-
final
-
stops
→ List<
GradientStop> -
Gradient stops (empty for solid fills).
final
- useForeground → bool
-
final
- x0 → double
-
Gradient geometry parameters.
final
- x1 → double
-
Gradient geometry parameters.
final
- y0 → double
-
Gradient geometry parameters.
final
- y1 → double
-
Gradient geometry parameters.
final
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited