CompileAndSignResult class
Constructors
-
CompileAndSignResult({required List<
CompiledModule> modules, required Uint8List signature, List<ShaderCompileError> shaderErrors = const []})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modules
→ List<
CompiledModule> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shaderErrors
→ List<
ShaderCompileError> -
Non-fatal shader-bake failures. Empty on success. A non-empty list means
one or more shaders were exported missing a requested backend variant.
final
- signature → Uint8List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
read(
BinaryReader reader) → CompileAndSignResult?