ImplementedType class

Constructors

ImplementedType({required String scriptName, required String interfaceTypeName, required List<ImplementedTypeProperty> inputs, required List<ImplementedTypeProperty> outputs, required List<String> userTypeNames, required List<String> dependencies, required List<String> implementedMethods})

Properties

dependencies List<String>
Direct dependencies (requires) for this module.
final
hashCode int
The hash code for this object.
no setterinherited
implementedMethods List<String>
Optional script methods (init/draw/drawCanvas/advance/...) present on the generator's returned table, detected by the workspace executing the generator and probing the returned table. Empty if the generator could not be executed.
final
inputs List<ImplementedTypeProperty>
final
interfaceTypeName String
final
outputs List<ImplementedTypeProperty>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptName String
final
userTypeNames List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

read(BinaryReader reader) ImplementedType?