RegisteredModule class
Constructors
Properties
-
dependencies
→ List<
String> -
final
- error → String
-
final
- generatorRef → int
-
final
- hasError → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUtility → bool
-
final
- moduleName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scriptId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited