setScriptSource abstract method
Set the source code for the script with scriptId. libraryId and
libraryVersionId scope it to a library version, zero scope is the
host file.
Implementation
Future<HighlightResult> setScriptSource(
String scriptId,
String scriptName,
String source, {
bool highlight = false,
int libraryId = 0,
int libraryVersionId = 0,
});