ShaderCompileError class
A per-source shader-bake failure reported by ScriptingWorkspace.compileAndSign (e.g. a shader that requested an HLSL variant but failed to compile it). When present, the corresponding shader was NOT embedded for that backend.
Constructors
- ShaderCompileError({required String scriptName, required String message})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable reason the shader variant was not produced.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scriptName → String
-
The shader source (script) name the failure is for.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited